#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 strict-identity
version:              0.1.0.0
visibility:           public
id:                   strict-identity-0.1.0.0-axXaihYrmKDIsWbouIf9O
key:                  strict-identity-0.1.0.0-axXaihYrmKDIsWbouIf9O
license:              BSD-3-Clause
maintainer:           carter at wellposed.com
author:               Carter Tazio Schonwald
homepage:             https://github.com/cartazio/strict-identity
synopsis:             Strict Identity Monad, handy for writing fast code!
description:
    strict Identity monad for writing strict performant code sanely

category:             Control
abi:                  609e660d4f76571af0d75a3e67accb04
exposed:              True
exposed-modules:      Control.Monad.StrictIdentity
import-dirs:          /usr/lib/ghc-9.6.6/site-local/strict-identity-0.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/strict-identity-0.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/strict-identity-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-strict-identity
hs-libraries:         HSstrict-identity-0.1.0.0-axXaihYrmKDIsWbouIf9O
depends:              base-4.18.2.1
haddock-interfaces:
    /usr/share/doc/haskell-strict-identity/html/strict-identity.haddock

haddock-html:         /usr/share/doc/haskell-strict-identity/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

